<?php

namespace Drupal\fathom_analytics\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form for Fathom Analytics settings.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'fathom_analytics_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'fathom_analytics.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('fathom_analytics.settings');

    $form['site_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Site ID'),
      '#description' => $this->t('Go to Fathom Analytics <a href=":url" target="_blank">settings page</a> to get your Site ID.', [
        ':url' => 'https://app.usefathom.com/#/settings/sites',
      ]),
      '#maxlength' => 150,
      '#size' => '20',
      '#default_value' => $config->get('site_id'),
    ];

    $form['custom_domain'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Custom domain'),
      '#description' => $this->t('Learn how to <a href=":url" target="_blank">setup a custom domain</a> to bypass ad-blockers.', [
        ':url' => 'https://usefathom.com/support/custom-domains',
      ]),
      '#placeholder' => 'moose.yourdomain.com',
      '#maxlength' => 250,
      '#size' => '40',
      '#default_value' => $config->get('custom_domain'),
    ];

    // Tracking settings.
    $form['tracking_settings'] = [
      '#type' => 'vertical_tabs',
      '#title' => $this->t('Tracking'),
      '#attached' => [
        'library' => [
          'fathom_analytics/fathom_analytics.admin',
        ],
      ],
    ];

    // Pages.
    $form['tracking']['path_tracking'] = [
      '#type' => 'details',
      '#title' => $this->t('Pages'),
      '#group' => 'tracking_settings',
    ];
    $form['tracking']['path_tracking']['tracking_path_mode'] = [
      '#type' => 'radios',
      '#title' => $this->t('Add tracking to specific pages'),
      '#options' => [
        $this->t('Every page except the listed pages'),
        $this->t('The listed pages only'),
      ],
      '#default_value' => $config->get('tracking.path_mode'),
    ];
    $tracking_pages = $config->get('tracking.path_pages');
    $form['tracking']['path_tracking']['tracking_path_pages'] = [
      '#type' => 'textarea',
      '#default_value' => !empty($tracking_pages) ? $tracking_pages : '',
      '#description' => $this->t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", ['%blog' => '/blog', '%blog-wildcard' => '/blog/*', '%front' => '<front>']),
      '#rows' => 10,
    ];

    // Roles.
    $tracking_roles = $config->get('tracking.role_roles');

    $form['tracking']['role_tracking'] = [
      '#type' => 'details',
      '#title' => $this->t('Roles'),
      '#group' => 'tracking_settings',
    ];
    $form['tracking']['role_tracking']['tracking_role_mode'] = [
      '#type' => 'radios',
      '#title' => $this->t('Add tracking for specific roles'),
      '#options' => [
        $this->t('Add to the selected roles only'),
        $this->t('Add to every role except the selected ones'),
      ],
      '#default_value' => $config->get('tracking.role_mode'),
    ];
    $form['tracking']['role_tracking']['tracking_role_roles'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Roles'),
      '#default_value' => !empty($tracking_roles) ? $tracking_roles : [],
      '#options' => array_map('\Drupal\Component\Utility\Html::escape', user_role_names()),
      '#description' => $this->t('If none of the roles are selected, all users will be tracked. If a user has any of the roles checked, that user will be tracked (or excluded, depending on the setting above).'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $this->config('fathom_analytics.settings')
      ->set('site_id', $form_state->getValue('site_id'))
      ->set('custom_domain', $form_state->getValue('custom_domain'))
      ->set('tracking.path_mode', $form_state->getValue('tracking_path_mode'))
      ->set('tracking.path_pages', $form_state->getValue('tracking_path_pages'))
      ->set('tracking.role_mode', $form_state->getValue('tracking_role_mode'))
      ->set('tracking.role_roles', $form_state->getValue('tracking_role_roles'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
